@@ -2,8 +2,8 @@ echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
 echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
 echo "" 												>> $EXTENSION/build_order.txt
 	
-# Required
-[[ $(command -v g-ir-inspect) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
+# Recommended
+[[ $(command -v gi-inspect-typelib) == "" ]] && echo "Installing glib" && extension --install glib && echo "Finished glib"
 # Optional
 if [[ $INSTALL_OPTIONAL != false ]]; then 
 	[[ $(command -v gtkdocize) == "" ]] && echo "Installing gtk_doc" && extension --install gtk_doc && echo "Finished gtk_doc"
